// ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.dbu.v0.dbuapi;

import "google/protobuf/empty.proto";

option csharp_namespace = "Ansys.Api.Dbu.V0.DbuApi";

// Api
//
service DbuApi{
  // Sets the current scripting version.
  rpc SetVersion(SetVersionRequest) returns(SetVersionResponse) ;

  // Sets the current scripting version.
  rpc GetVersion(google.protobuf.Empty) returns(GetVersionResponse) ;
}

message GetVersionResponse{
  ApiVersion version = 1;
}

message SetVersionRequest{
  // The set api operation being requested.
  ApiVersion version = 1;
}

message SetVersionResponse{
  string result = 1;
}

enum ApiVersion {
  INVALID = 0;
  V_21 = 21;
  V_22 = 22;
  V_231 = 231;
  V_232 = 232;
  V_241 = 241;
}
