// ©2023, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.dbu.v0.drivingdimensions;

import "ansys/api/dbu/v0/dbumodels.proto";

option csharp_namespace = "Ansys.Api.Dbu.V0.DrivingDimensions";

service DrivingDimensions{
  // Gets a driving dimension.
  rpc Get(EntityIdentifier) returns(DrivingDimension);

  // Lists all driving dimensions.
  rpc GetAll(GetAllRequest) returns(GetAllResponse);

  // Upates a driving dimension.
  rpc Update(UpdateRequest) returns(DrivingDimension);
}

message GetAllRequest{
  // The parent, which must be empty.
  string parent = 1;
}

message GetAllResponse{
  // The driving dimensions on this page.
  repeated DrivingDimension driving_dimensions = 1;
}

message UpdateRequest{
  // The driving dimension to update.
  DrivingDimension driving_dimension = 1;
}
